% CC0 - To the extent possible under law, Roberto Dyke has waived all copyright
% and related or neighboring rights to this ground-truth correspondence
% viewing code.
obj_src = '../SHREC19_hires';
gt_src = '../groundtruths_hires/sparse';

files = dir(fullfile(gt_src,'*.baryc_gt'));

for fi=1:numel(files)
    filename = files(fi).name;
    parts = split(filename,'_');
    
    target = fullfile(obj_src,'models',[filename(1:8),'.obj']);
    source = fullfile(obj_src,'models',[filename(10:17),'.obj']);
    
    M = load_obj(source);
    N = load_obj(target);
    
    gt_baryc = load(fullfile(files(fi).folder,files(fi).name));

    vids = gt_baryc(:,1) > 0;
    p1 = M.VERT(vids,:);
    b = gt_baryc(vids,:);    
    p2 = N.VERT(N.TRIV(b(:,1),1),:).*b(:,2) + N.VERT(N.TRIV(b(:,1),2),:).*b(:,3) + N.VERT(N.TRIV(b(:,1),3),:).*b(:,4); % baryc to 3D
    RGB = (p1 - min(p1,[],1)) ./ (max(p1,[],1) - min(p1,[],1));
    
    %{ 
    % Rough method for binary 0/1 barycentric coordinates
    vids = N.TRIV(gt_baryc(:,1),:)';
    vids = vids(logical(gt_baryc(:,2:end))');    
    corr = [find(gt_baryc(:,1) > 0), vids];
    RGB = (M.VERT - min(M.VERT,[],1)) ./ (max(M.VERT,[],1) - min(M.VERT,[],1));
    p1 = M.VERT(corr(:,1),:);
    p2 = N.VERT(corr(:,2),:);
    %}
    
    xshift = max(M.VERT(:,1)) + abs(min(N.VERT(:,1)));
    fig = figure;
    trisurf(M.TRIV,M.VERT(:,1),M.VERT(:,2),M.VERT(:,3),'FaceColor','w','EdgeAlpha',0.1);
    hold on;
    trisurf(N.TRIV,N.VERT(:,1)+xshift,N.VERT(:,2),N.VERT(:,3),'FaceColor','w','EdgeAlpha',0.1);
    scatter3(p1(:,1),p1(:,2),p1(:,3),'filled','CData',RGB);
    scatter3(p2(:,1)+xshift,p2(:,2),p2(:,3),'filled','CData',RGB);
    plot3(reshape([p1(:,1),p2(:,1)+xshift,NaN(size(p1,1),1)]',size(p1,1)*3,1),...
          reshape([p1(:,2),p2(:,2),NaN(size(p1,1),1)]',size(p1,1)*3,1),...
          reshape([p1(:,3),p2(:,3),NaN(size(p1,1),1)]',size(p1,1)*3,1));
    hold off;
    axis equal off;
    text(0,0,'Press any key to show the next pair...','Units','normalized');
    title(sprintf('%i/%i target: %s, source: %s',fi,numel(files),filename(1:8),filename(10:17)),'Interpreter','none');
    drawnow;
    pause;
    close(fig);
end